==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ModelClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ForStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ForStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.InstanceReferenceDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.InstanceReferenceDataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariableSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateNoVariableSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassInstanceParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_FIOSet;
import io.ciera.tool.sql.ooaofooa.selection.ChainLinkSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_FIOSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.ChainLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectFromInstancesWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ClassStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.InstanceStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClass;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ImportedClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceHandleSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_INSSetImpl;

import java.util.Arrays;
import java.util.List;


public class ModelClassSetImpl extends InstanceSet<ModelClassSet,ModelClass> implements ModelClassSet {

    // attributes
    @Override
    public void setNumb( int m_Numb ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setNumb( m_Numb );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setName( m_Name );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setKey_Lett( String m_Key_Lett ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setKey_Lett( m_Key_Lett );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public ImportedClassSet R101_has_presence_in_other_subsystems_ImportedClass() throws XtumlException {
        ImportedClassSet importedclassset = new ImportedClassSetImpl();
        for ( ModelClass modelclass : this ) importedclassset.addAll( modelclass.R101_has_presence_in_other_subsystems_ImportedClass() );
        return importedclassset;
    }
    @Override
    public O_ATTRSet R102_has_characteristics_abstracted_by_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( ModelClass modelclass : this ) o_attrset.addAll( modelclass.R102_has_characteristics_abstracted_by_O_ATTR() );
        return o_attrset;
    }
    @Override
    public ClassIdentifierSet R104_is_identified_by_ClassIdentifier() throws XtumlException {
        ClassIdentifierSet classidentifierset = new ClassIdentifierSetImpl();
        for ( ModelClass modelclass : this ) classidentifierset.addAll( modelclass.R104_is_identified_by_ClassIdentifier() );
        return classidentifierset;
    }
    @Override
    public O_TFRSet R115_may_contain_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( ModelClass modelclass : this ) o_tfrset.addAll( modelclass.R115_may_contain_O_TFR() );
        return o_tfrset;
    }
    @Override
    public InstanceReferenceDataTypeSet R123_is_available_as_a_reference_by_InstanceReferenceDataType() throws XtumlException {
        InstanceReferenceDataTypeSet instancereferencedatatypeset = new InstanceReferenceDataTypeSetImpl();
        for ( ModelClass modelclass : this ) instancereferencedatatypeset.addAll( modelclass.R123_is_available_as_a_reference_by_InstanceReferenceDataType() );
        return instancereferencedatatypeset;
    }
    @Override
    public ClassInAssociationSet R201_has_instance_associations_abstracted_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ModelClass modelclass : this ) classinassociationset.addAll( modelclass.R201_has_instance_associations_abstracted_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ModelInstSet R409_is_basis_for_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( ModelClass modelclass : this ) modelinstset.add( modelclass.R409_is_basis_for_ModelInst() );
        return modelinstset;
    }
    @Override
    public InstanceStateMachineSet R518_InstanceStateMachine() throws XtumlException {
        InstanceStateMachineSet instancestatemachineset = new InstanceStateMachineSetImpl();
        for ( ModelClass modelclass : this ) instancestatemachineset.add( modelclass.R518_InstanceStateMachine() );
        return instancestatemachineset;
    }
    @Override
    public ClassStateMachineSet R519_ClassStateMachine() throws XtumlException {
        ClassStateMachineSet classstatemachineset = new ClassStateMachineSetImpl();
        for ( ModelClass modelclass : this ) classstatemachineset.add( modelclass.R519_ClassStateMachine() );
        return classstatemachineset;
    }
    @Override
    public ForStmtSet R670_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( ModelClass modelclass : this ) forstmtset.addAll( modelclass.R670_ForStmt() );
        return forstmtset;
    }
    @Override
    public CreateSet R671_Create() throws XtumlException {
        CreateSet createset = new CreateSetImpl();
        for ( ModelClass modelclass : this ) createset.addAll( modelclass.R671_Create() );
        return createset;
    }
    @Override
    public CreateNoVariableSet R672_CreateNoVariable() throws XtumlException {
        CreateNoVariableSet createnovariableset = new CreateNoVariableSetImpl();
        for ( ModelClass modelclass : this ) createnovariableset.addAll( modelclass.R672_CreateNoVariable() );
        return createnovariableset;
    }
    @Override
    public SelectFromInstancesWhereSet R676_SelectFromInstancesWhere() throws XtumlException {
        SelectFromInstancesWhereSet selectfrominstanceswhereset = new SelectFromInstancesWhereSetImpl();
        for ( ModelClass modelclass : this ) selectfrominstanceswhereset.addAll( modelclass.R676_SelectFromInstancesWhere() );
        return selectfrominstanceswhereset;
    }
    @Override
    public ACT_FIOSet R677_ACT_FIO() throws XtumlException {
        ACT_FIOSet act_fioset = new ACT_FIOSetImpl();
        for ( ModelClass modelclass : this ) act_fioset.addAll( modelclass.R677_ACT_FIO() );
        return act_fioset;
    }
    @Override
    public ChainLinkSet R678_ChainLink() throws XtumlException {
        ChainLinkSet chainlinkset = new ChainLinkSetImpl();
        for ( ModelClass modelclass : this ) chainlinkset.addAll( modelclass.R678_ChainLink() );
        return chainlinkset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ModelClass modelclass : this ) packageableelementset.add( modelclass.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public InstanceHandleSet R818_InstanceHandle() throws XtumlException {
        InstanceHandleSet instancehandleset = new InstanceHandleSetImpl();
        for ( ModelClass modelclass : this ) instancehandleset.addAll( modelclass.R818_InstanceHandle() );
        return instancehandleset;
    }
    @Override
    public V_INSSet R819_V_INS() throws XtumlException {
        V_INSSet v_insset = new V_INSSetImpl();
        for ( ModelClass modelclass : this ) v_insset.addAll( modelclass.R819_V_INS() );
        return v_insset;
    }
    @Override
    public ClassInstanceParticipantSet R934_represents_participant_of_ClassInstanceParticipant() throws XtumlException {
        ClassInstanceParticipantSet classinstanceparticipantset = new ClassInstanceParticipantSetImpl();
        for ( ModelClass modelclass : this ) classinstanceparticipantset.addAll( modelclass.R934_represents_participant_of_ClassInstanceParticipant() );
        return classinstanceparticipantset;
    }
    @Override
    public ClassParticipantSet R939_represents_participant_of_ClassParticipant() throws XtumlException {
        ClassParticipantSet classparticipantset = new ClassParticipantSetImpl();
        for ( ModelClass modelclass : this ) classparticipantset.addAll( modelclass.R939_represents_participant_of_ClassParticipant() );
        return classparticipantset;
    }


    @Override
    public ModelClass nullElement() {
        return ModelClassImpl.EMPTY_MODELCLASS;
    }

    @Override
    public ModelClassSet emptySet() {
      return new ModelClassSetImpl();
    }

    @Override
    public ModelClassSet value() {
        return this;
    }

    @Override
    public List<ModelClass> elements() {
        ModelClass[] elements = toArray(new ModelClass[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/ModelClassSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.classes.ModelInstSet;
import io.ciera.tool.sql.architecture.classes.impl.ModelInstSetImpl;
import io.ciera.tool.sql.ooaofooa.association.ClassInAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassInAssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.body.ForStmtSet;
import io.ciera.tool.sql.ooaofooa.body.impl.ForStmtSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.InstanceReferenceDataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.InstanceReferenceDataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateNoVariableSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.CreateSet;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateNoVariableSetImpl;
import io.ciera.tool.sql.ooaofooa.instanceaccess.impl.CreateSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.ClassInstanceParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.ClassParticipantSet;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassInstanceParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.interaction.impl.ClassParticipantSetImpl;
import io.ciera.tool.sql.ooaofooa.packageableelement.PackageableElementSet;
import io.ciera.tool.sql.ooaofooa.packageableelement.impl.PackageableElementSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.ACT_FIOSet;
import io.ciera.tool.sql.ooaofooa.selection.ChainLinkSet;
import io.ciera.tool.sql.ooaofooa.selection.SelectFromInstancesWhereSet;
import io.ciera.tool.sql.ooaofooa.selection.impl.ACT_FIOSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.ChainLinkSetImpl;
import io.ciera.tool.sql.ooaofooa.selection.impl.SelectFromInstancesWhereSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.ClassStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.InstanceStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.ClassStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.InstanceStateMachineSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.ClassIdentifierSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ImportedClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClass;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_ATTRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ClassIdentifierSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ImportedClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_ATTRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.value.InstanceHandleSet;
import io.ciera.tool.sql.ooaofooa.value.V_INSSet;
import io.ciera.tool.sql.ooaofooa.value.impl.InstanceHandleSetImpl;
import io.ciera.tool.sql.ooaofooa.value.impl.V_INSSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class ModelClassSetImpl extends InstanceSet<ModelClassSet,ModelClass> implements ModelClassSet {

    public ModelClassSetImpl() {
    }

    public ModelClassSetImpl(Comparator<? super ModelClass> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setName( m_Name );
    }
    @Override
    public void setKey_Lett( String m_Key_Lett ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setKey_Lett( m_Key_Lett );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setDescrip( m_Descrip );
    }
    @Override
    public void setSS_IDdeprecated( UniqueId m_SS_IDdeprecated ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setSS_IDdeprecated( m_SS_IDdeprecated );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setNumb( int m_Numb ) throws XtumlException {
        for ( ModelClass modelclass : this ) modelclass.setNumb( m_Numb );
    }


    // selections
    @Override
    public ImportedClassSet R101_has_presence_in_other_subsystems_ImportedClass() throws XtumlException {
        ImportedClassSet importedclassset = new ImportedClassSetImpl();
        for ( ModelClass modelclass : this ) importedclassset.addAll( modelclass.R101_has_presence_in_other_subsystems_ImportedClass() );
        return importedclassset;
    }
    @Override
    public O_ATTRSet R102_has_characteristics_abstracted_by_O_ATTR() throws XtumlException {
        O_ATTRSet o_attrset = new O_ATTRSetImpl();
        for ( ModelClass modelclass : this ) o_attrset.addAll( modelclass.R102_has_characteristics_abstracted_by_O_ATTR() );
        return o_attrset;
    }
    @Override
    public ClassIdentifierSet R104_is_identified_by_ClassIdentifier() throws XtumlException {
        ClassIdentifierSet classidentifierset = new ClassIdentifierSetImpl();
        for ( ModelClass modelclass : this ) classidentifierset.addAll( modelclass.R104_is_identified_by_ClassIdentifier() );
        return classidentifierset;
    }
    @Override
    public O_TFRSet R115_may_contain_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( ModelClass modelclass : this ) o_tfrset.addAll( modelclass.R115_may_contain_O_TFR() );
        return o_tfrset;
    }
    @Override
    public InstanceReferenceDataTypeSet R123_is_available_as_a_reference_by_InstanceReferenceDataType() throws XtumlException {
        InstanceReferenceDataTypeSet instancereferencedatatypeset = new InstanceReferenceDataTypeSetImpl();
        for ( ModelClass modelclass : this ) instancereferencedatatypeset.addAll( modelclass.R123_is_available_as_a_reference_by_InstanceReferenceDataType() );
        return instancereferencedatatypeset;
    }
    @Override
    public ClassInAssociationSet R201_has_instance_associations_abstracted_ClassInAssociation() throws XtumlException {
        ClassInAssociationSet classinassociationset = new ClassInAssociationSetImpl();
        for ( ModelClass modelclass : this ) classinassociationset.addAll( modelclass.R201_has_instance_associations_abstracted_ClassInAssociation() );
        return classinassociationset;
    }
    @Override
    public ModelInstSet R409_is_basis_for_ModelInst() throws XtumlException {
        ModelInstSet modelinstset = new ModelInstSetImpl();
        for ( ModelClass modelclass : this ) modelinstset.add( modelclass.R409_is_basis_for_ModelInst() );
        return modelinstset;
    }
    @Override
    public InstanceStateMachineSet R518_InstanceStateMachine() throws XtumlException {
        InstanceStateMachineSet instancestatemachineset = new InstanceStateMachineSetImpl();
        for ( ModelClass modelclass : this ) instancestatemachineset.add( modelclass.R518_InstanceStateMachine() );
        return instancestatemachineset;
    }
    @Override
    public ClassStateMachineSet R519_ClassStateMachine() throws XtumlException {
        ClassStateMachineSet classstatemachineset = new ClassStateMachineSetImpl();
        for ( ModelClass modelclass : this ) classstatemachineset.add( modelclass.R519_ClassStateMachine() );
        return classstatemachineset;
    }
    @Override
    public ForStmtSet R670_ForStmt() throws XtumlException {
        ForStmtSet forstmtset = new ForStmtSetImpl();
        for ( ModelClass modelclass : this ) forstmtset.addAll( modelclass.R670_ForStmt() );
        return forstmtset;
    }
    @Override
    public CreateSet R671_Create() throws XtumlException {
        CreateSet createset = new CreateSetImpl();
        for ( ModelClass modelclass : this ) createset.addAll( modelclass.R671_Create() );
        return createset;
    }
    @Override
    public CreateNoVariableSet R672_CreateNoVariable() throws XtumlException {
        CreateNoVariableSet createnovariableset = new CreateNoVariableSetImpl();
        for ( ModelClass modelclass : this ) createnovariableset.addAll( modelclass.R672_CreateNoVariable() );
        return createnovariableset;
    }
    @Override
    public SelectFromInstancesWhereSet R676_SelectFromInstancesWhere() throws XtumlException {
        SelectFromInstancesWhereSet selectfrominstanceswhereset = new SelectFromInstancesWhereSetImpl();
        for ( ModelClass modelclass : this ) selectfrominstanceswhereset.addAll( modelclass.R676_SelectFromInstancesWhere() );
        return selectfrominstanceswhereset;
    }
    @Override
    public ACT_FIOSet R677_ACT_FIO() throws XtumlException {
        ACT_FIOSet act_fioset = new ACT_FIOSetImpl();
        for ( ModelClass modelclass : this ) act_fioset.addAll( modelclass.R677_ACT_FIO() );
        return act_fioset;
    }
    @Override
    public ChainLinkSet R678_ChainLink() throws XtumlException {
        ChainLinkSet chainlinkset = new ChainLinkSetImpl();
        for ( ModelClass modelclass : this ) chainlinkset.addAll( modelclass.R678_ChainLink() );
        return chainlinkset;
    }
    @Override
    public PackageableElementSet R8001_is_a_PackageableElement() throws XtumlException {
        PackageableElementSet packageableelementset = new PackageableElementSetImpl();
        for ( ModelClass modelclass : this ) packageableelementset.add( modelclass.R8001_is_a_PackageableElement() );
        return packageableelementset;
    }
    @Override
    public InstanceHandleSet R818_InstanceHandle() throws XtumlException {
        InstanceHandleSet instancehandleset = new InstanceHandleSetImpl();
        for ( ModelClass modelclass : this ) instancehandleset.addAll( modelclass.R818_InstanceHandle() );
        return instancehandleset;
    }
    @Override
    public V_INSSet R819_V_INS() throws XtumlException {
        V_INSSet v_insset = new V_INSSetImpl();
        for ( ModelClass modelclass : this ) v_insset.addAll( modelclass.R819_V_INS() );
        return v_insset;
    }
    @Override
    public ClassInstanceParticipantSet R934_represents_participant_of_ClassInstanceParticipant() throws XtumlException {
        ClassInstanceParticipantSet classinstanceparticipantset = new ClassInstanceParticipantSetImpl();
        for ( ModelClass modelclass : this ) classinstanceparticipantset.addAll( modelclass.R934_represents_participant_of_ClassInstanceParticipant() );
        return classinstanceparticipantset;
    }
    @Override
    public ClassParticipantSet R939_represents_participant_of_ClassParticipant() throws XtumlException {
        ClassParticipantSet classparticipantset = new ClassParticipantSetImpl();
        for ( ModelClass modelclass : this ) classparticipantset.addAll( modelclass.R939_represents_participant_of_ClassParticipant() );
        return classparticipantset;
    }


    @Override
    public ModelClass nullElement() {
        return ModelClassImpl.EMPTY_MODELCLASS;
    }

    @Override
    public ModelClassSet emptySet() {
      return new ModelClassSetImpl();
    }

    @Override
    public ModelClassSet emptySet(Comparator<? super ModelClass> comp) {
      return new ModelClassSetImpl(comp);
    }

    @Override
    public ModelClassSet value() {
        return this;
    }

    @Override
    public List<ModelClass> elements() {
        ModelClass[] elements = toArray(new ModelClass[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
